# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseCreditHistoryItem(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'balance_from': 'float',
        'balance_to': 'float',
        'description': 'str',
        'history_time_in_seconds': 'float',
        'history_type': 'str'
    }

    attribute_map = {
        'balance_from': 'balance_from',
        'balance_to': 'balance_to',
        'description': 'description',
        'history_time_in_seconds': 'history_time_in_seconds',
        'history_type': 'history_type'
    }

    def __init__(self, balance_from=None, balance_to=None, description=None, history_time_in_seconds=None, history_type=None, local_vars_configuration=None):  # noqa: E501
        """ResponseCreditHistoryItem - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._balance_from = None
        self._balance_to = None
        self._description = None
        self._history_time_in_seconds = None
        self._history_type = None
        self.discriminator = None

        if balance_from is not None:
            self.balance_from = balance_from
        if balance_to is not None:
            self.balance_to = balance_to
        if description is not None:
            self.description = description
        if history_time_in_seconds is not None:
            self.history_time_in_seconds = history_time_in_seconds
        if history_type is not None:
            self.history_type = history_type

    @property
    def balance_from(self):
        """Gets the balance_from of this ResponseCreditHistoryItem.  # noqa: E501


        :return: The balance_from of this ResponseCreditHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._balance_from

    @balance_from.setter
    def balance_from(self, balance_from):
        """Sets the balance_from of this ResponseCreditHistoryItem.


        :param balance_from: The balance_from of this ResponseCreditHistoryItem.  # noqa: E501
        :type balance_from: float
        """

        self._balance_from = balance_from

    @property
    def balance_to(self):
        """Gets the balance_to of this ResponseCreditHistoryItem.  # noqa: E501


        :return: The balance_to of this ResponseCreditHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._balance_to

    @balance_to.setter
    def balance_to(self, balance_to):
        """Sets the balance_to of this ResponseCreditHistoryItem.


        :param balance_to: The balance_to of this ResponseCreditHistoryItem.  # noqa: E501
        :type balance_to: float
        """

        self._balance_to = balance_to

    @property
    def description(self):
        """Gets the description of this ResponseCreditHistoryItem.  # noqa: E501


        :return: The description of this ResponseCreditHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this ResponseCreditHistoryItem.


        :param description: The description of this ResponseCreditHistoryItem.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def history_time_in_seconds(self):
        """Gets the history_time_in_seconds of this ResponseCreditHistoryItem.  # noqa: E501


        :return: The history_time_in_seconds of this ResponseCreditHistoryItem.  # noqa: E501
        :rtype: float
        """
        return self._history_time_in_seconds

    @history_time_in_seconds.setter
    def history_time_in_seconds(self, history_time_in_seconds):
        """Sets the history_time_in_seconds of this ResponseCreditHistoryItem.


        :param history_time_in_seconds: The history_time_in_seconds of this ResponseCreditHistoryItem.  # noqa: E501
        :type history_time_in_seconds: float
        """

        self._history_time_in_seconds = history_time_in_seconds

    @property
    def history_type(self):
        """Gets the history_type of this ResponseCreditHistoryItem.  # noqa: E501


        :return: The history_type of this ResponseCreditHistoryItem.  # noqa: E501
        :rtype: str
        """
        return self._history_type

    @history_type.setter
    def history_type(self, history_type):
        """Sets the history_type of this ResponseCreditHistoryItem.


        :param history_type: The history_type of this ResponseCreditHistoryItem.  # noqa: E501
        :type history_type: str
        """
        allowed_values = ["WorkloadRunTime", "Manual", "PeriodicDeduction", "Creation", "Expiry"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and history_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `history_type` ({0}), must be one of {1}"  # noqa: E501
                .format(history_type, allowed_values)
            )

        self._history_type = history_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseCreditHistoryItem):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseCreditHistoryItem):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1SingleVariableSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'default_value': 'V1VariableValue',
        'description': 'str',
        'name': 'str',
        'options': 'list[str]',
        'regexp_pattern': 'str',
        'required': 'bool',
        'type': 'str'
    }

    attribute_map = {
        'default_value': 'default_value',
        'description': 'description',
        'name': 'name',
        'options': 'options',
        'regexp_pattern': 'regexp_pattern',
        'required': 'required',
        'type': 'type'
    }

    def __init__(self, default_value=None, description=None, name=None, options=None, regexp_pattern=None, required=None, type=None, local_vars_configuration=None):  # noqa: E501
        """V1SingleVariableSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._default_value = None
        self._description = None
        self._name = None
        self._options = None
        self._regexp_pattern = None
        self._required = None
        self._type = None
        self.discriminator = None

        if default_value is not None:
            self.default_value = default_value
        if description is not None:
            self.description = description
        self.name = name
        if options is not None:
            self.options = options
        self.regexp_pattern = regexp_pattern
        if required is not None:
            self.required = required
        self.type = type

    @property
    def default_value(self):
        """Gets the default_value of this V1SingleVariableSpec.  # noqa: E501


        :return: The default_value of this V1SingleVariableSpec.  # noqa: E501
        :rtype: V1VariableValue
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """Sets the default_value of this V1SingleVariableSpec.


        :param default_value: The default_value of this V1SingleVariableSpec.  # noqa: E501
        :type default_value: V1VariableValue
        """

        self._default_value = default_value

    @property
    def description(self):
        """Gets the description of this V1SingleVariableSpec.  # noqa: E501


        :return: The description of this V1SingleVariableSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1SingleVariableSpec.


        :param description: The description of this V1SingleVariableSpec.  # noqa: E501
        :type description: str
        """

        self._description = description

    @property
    def name(self):
        """Gets the name of this V1SingleVariableSpec.  # noqa: E501


        :return: The name of this V1SingleVariableSpec.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1SingleVariableSpec.


        :param name: The name of this V1SingleVariableSpec.  # noqa: E501
        :type name: str
        """
        if self.local_vars_configuration.client_side_validation and name is None:  # noqa: E501
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def options(self):
        """Gets the options of this V1SingleVariableSpec.  # noqa: E501


        :return: The options of this V1SingleVariableSpec.  # noqa: E501
        :rtype: list[str]
        """
        return self._options

    @options.setter
    def options(self, options):
        """Sets the options of this V1SingleVariableSpec.


        :param options: The options of this V1SingleVariableSpec.  # noqa: E501
        :type options: list[str]
        """

        self._options = options

    @property
    def regexp_pattern(self):
        """Gets the regexp_pattern of this V1SingleVariableSpec.  # noqa: E501


        :return: The regexp_pattern of this V1SingleVariableSpec.  # noqa: E501
        :rtype: str
        """
        return self._regexp_pattern

    @regexp_pattern.setter
    def regexp_pattern(self, regexp_pattern):
        """Sets the regexp_pattern of this V1SingleVariableSpec.


        :param regexp_pattern: The regexp_pattern of this V1SingleVariableSpec.  # noqa: E501
        :type regexp_pattern: str
        """

        self._regexp_pattern = regexp_pattern

    @property
    def required(self):
        """Gets the required of this V1SingleVariableSpec.  # noqa: E501


        :return: The required of this V1SingleVariableSpec.  # noqa: E501
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """Sets the required of this V1SingleVariableSpec.


        :param required: The required of this V1SingleVariableSpec.  # noqa: E501
        :type required: bool
        """

        self._required = required

    @property
    def type(self):
        """Gets the type of this V1SingleVariableSpec.  # noqa: E501


        :return: The type of this V1SingleVariableSpec.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this V1SingleVariableSpec.


        :param type: The type of this V1SingleVariableSpec.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501
        allowed_values = ["string", "choice"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"  # noqa: E501
                .format(type, allowed_values)
            )

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1SingleVariableSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1SingleVariableSpec):
            return True

        return self.to_dict() != other.to_dict()
